%ANALYTICAL_SLOPE.M
%This script calculates all the analytical values for the seabed slope case study

close all
clear all
clc

OD = 0.4229              ;   %outer diamater [m]
t = 0.0191               ;   %Wall thickness
Ae = 3.14*(OD/2)^2       ;   %Area, outside diameter [m^2]
Ai = 1                   ;   %Area, inside diameter
As = 1                   ;   %Area, pipe wall
E = 207000000000         ;   %Young's Modulus
EA = E*Ae                ;   %axial stiffness
W = 43.3                 ;   %submerged unit weight [N/m]
L = 3000                 ;   %length of pipeline
p_i = 15800000           ;   %internal pressure
p_e = 30700000           ;   %external pressure
p_2 = 13900000           ;   %constant pressure
p_1 = p_i                ;   %constant pressure
Sr = 5000                ;   %SCR tension [N]
kappa = 1.17*10^-5       ;   %coeff of thermal expansion
theta = 78               ;   %operating temperature
theta2 = 52.25           ;   %temperature at last time step for the last node from temp files
theta1 = 58.70           ;   %temperature at the first time step at the first node from temp files
nu = 0.3                 ;   %Poisson's ratio

mu = 0.279               ;   %friction coeff
alfa = 0                 ;   %seabed slope

f = mu*W                 ;   %axial friction force


for i = 1:6
    
    dtr = (2*3.14)/180;
    
%General equations:

deltaP = (-(p_2 - p_1)*Ai*(1 - (2*nu))) - (E*As*kappa*(theta2 - theta1)); %change in fully constrained force

f_star = (abs(deltaP))/L;    %friction force at which cyclic constraint occurs

fprintf('\nThe change in fully constrained force is %.4f [N]', deltaP)
fprintf('\nf_star is %.4f [N/m]', f_star)


%Sloped seabed case:
fprintf('\n\nThe analytical results for alfa = %.1f [deg]:',alfa)

Xab = (L*(tan(alfa*dtr)))/mu;    %Length between virtual anchors
deltaSs = -W*L*((mu*(cos(alfa*dtr))) - (abs(sin(alfa*dtr))));    %change in force over the length Xab
deltas = (((abs(deltaP)) + ((W*L)*abs(sin(alfa*dtr))) - (W*L*mu*(cos(alfa*dtr))))*L*(tan(alfa*dtr)))/(EA*mu);    %walk per cycle for the slope case

fprintf('\nThe length between virtual anchors is %.4f [m]', Xab)
fprintf('\nThe change in effective axial force over X_ab is %.4f [N]', deltaSs)
fprintf('\nThe walk per cycle is %.4f [m] \n', deltas)


%Writing to file:

fid = fopen('analytical_pos_new.dat','a');
fprintf(fid,'%.4f \n\n',deltas);

alfa = alfa - 0.5;


end

fclose(fid);

fprintf('\n')
