%ANGLE.M
%This script opens and reads displacement files/.dat files, and assign the
%values to new matrices. The displacements for the middle node are
%plotted, as well as angle vs. walk per cycle. This is done for both
%positive and negative angles.

clear all
close all
clc


N = 6;  %Number of files

for p = 1:2     %1 = positive values, 2 = negative values
    
    fprintf('\n')
    
    if p == 1
        
        %Opening the displacement files for positive angles
        
        disp_0_0 = fopen('0_0_middle.dat');
        disp_0_5 = fopen('0_5_middle.dat');
        disp_1_0 = fopen('1_0_middle.dat');
        disp_1_5 = fopen('1_5_middle.dat');
        disp_2_0 = fopen('2_0_middle.dat');
        disp_2_5 = fopen('2_5_middle.dat');
        
    else
        
        %Opening the displacement files for negative angles
        
        disp_0_0 = fopen('0_0_middle.dat');
        disp_0_5 = fopen('0_5_neg_middle.dat');
        disp_1_0 = fopen('1_0_neg_middle.dat');
        disp_1_5 = fopen('1_5_neg_middle.dat');
        disp_2_0 = fopen('2_0_neg_middle.dat');
        disp_2_5 = fopen('2_5_neg_middle.dat');
        
    end

% The text file is read:

m = 4851;       %Number of input lines/time steps in the text file
n = 2;          %Number of coloumns

dispinfo_0_0 = (fscanf(disp_0_0, '%d %f', [n,m]))';
dispinfo_0_5 = (fscanf(disp_0_5, '%d %f', [n,m]))';
dispinfo_1_0 = (fscanf(disp_1_0, '%d %f', [n,m]))';
dispinfo_1_5 = (fscanf(disp_1_5, '%d %f', [n,m]))';
dispinfo_2_0 = (fscanf(disp_2_0, '%d %f', [n,m]))';
dispinfo_2_5 = (fscanf(disp_2_5, '%d %f', [n,m]))';

time_step = dispinfo_0_0(:,1);

displ_0_0 = dispinfo_0_0(:,2);
displ_0_5 = dispinfo_0_5(:,2);
displ_1_0 = dispinfo_1_0(:,2);
displ_1_5 = dispinfo_1_5(:,2);
displ_2_0 = dispinfo_2_0(:,2);
displ_2_5 = dispinfo_2_5(:,2);


%Writing to screen:

fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_0_0(m))
fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_0_5(m))
fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_1_0(m))
fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_1_5(m))
fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_2_0(m))
fprintf('\nThe overall walk after 12 cycles is %.4f [m] for the middle node', displ_2_5(m))
fprintf('\n')

%Plotting displacement for each time step:

figure;
hold on
h=gca;
set(h,'fontsize',26)
plot(time_step,displ_2_5,'k','linewidth',2);
plot(time_step,displ_2_0,'m','linewidth',2);
plot(time_step,displ_1_5,'c','linewidth',2);
plot(time_step,displ_1_0,'y','linewidth',2);
plot(time_step,displ_0_5,'r','linewidth',2);
plot(time_step,displ_0_0,'g','linewidth',2);
line([426 426],[-2 2.5],'linewidth',1)
line([826 826],[-2 2.5],'linewidth',1)
line([1226 1226],[-2 2.5],'linewidth',1)
line([1626 1626],[-2 2.5],'linewidth',1)
line([2026 2026],[-2 2.5],'linewidth',1)
line([2426 2426],[-2 2.5],'linewidth',1)
line([2826 2826],[-2 2.5],'linewidth',1)
line([3226 3226],[-2 2.5],'linewidth',1)
line([3626 3626],[-2 2.5],'linewidth',1)
line([4026 4026],[-2 2.5],'linewidth',1)
line([4426 4426],[-2 2.5],'linewidth',1)
line([4826 4826],[-2 2.5],'linewidth',1)
title('Axial displacement at the middle node');
xlabel('Time step [s]');
ylabel('Displacement [m]');

if p == 1
    
    legend('\alpha = 2.5','\alpha = 2.0','\alpha = 1.5','\alpha = 1.0','\alpha = 0.5','\alpha = 0.0');
    axis([0 5000 0 2.3])
    
else
    
    legend('\alpha = -2.5','\alpha = -2.0','\alpha = -1.5','\alpha = -1.0','\alpha = -0.5','\alpha = 0.0');
    axis([0 5000 -1.7 0.5])
    
end
    
axis square
%grid on


%Walk per cycle:

k = 12;         %Number of cycles
t = 400;        %One cycle is t time steps

c_temp = zeros(k,1);    %Temporary variable for c
c = zeros(k,1);         %Matrix with time steps at a given point in each cycle
c_temp(1) = 426;

w_0_0 = zeros(k,1);
w_0_5 = zeros(k,1);
w_1_0 = zeros(k,1);
w_1_5 = zeros(k,1);
w_2_0 = zeros(k,1);
w_2_5 = zeros(k,1);

format long

for i = 1:k
    
    c_temp(i+1) = c_temp(i) + t;
    c(i) = c_temp(i);
    
    w_0_0(i) = displ_0_0(c(i));
    w_0_5(i) = displ_0_5(c(i));
    w_1_0(i) = displ_1_0(c(i));
    w_1_5(i) = displ_1_5(c(i));
    w_2_0(i) = displ_2_0(c(i));
    w_2_5(i) = displ_2_5(c(i));
             
end

d_w_0_0 = zeros(k,1);
d_w_0_5 = zeros(k,1);
d_w_1_0 = zeros(k,1);
d_w_1_5 = zeros(k,1);
d_w_2_0 = zeros(k,1);
d_w_2_5 = zeros(k,1);

d_w_0_0(1) = w_0_0(1);
d_w_0_5(1) = w_0_5(1);
d_w_1_0(1) = w_1_0(1);
d_w_1_5(1) = w_1_5(1);
d_w_2_0(1) = w_2_0(1);
d_w_2_5(1) = w_2_5(1);

for j = 2:k
    
    d_w_0_0(j) = w_0_0(j) - w_0_0(j-1);
    d_w_0_5(j) = w_0_5(j) - w_0_5(j-1);
    d_w_1_0(j) = w_1_0(j) - w_1_0(j-1);
    d_w_1_5(j) = w_1_5(j) - w_1_5(j-1);
    d_w_2_0(j) = w_2_0(j) - w_2_0(j-1);
    d_w_2_5(j) = w_2_5(j) - w_2_5(j-1);
    
end


%Walk per cycle based on the k - 2 last cycles

l = k-2;

w_c_0_0_mean = zeros(l,1);
w_c_0_5_mean = zeros(l,1);
w_c_1_0_mean = zeros(l,1);
w_c_1_5_mean = zeros(l,1);
w_c_2_0_mean = zeros(l,1);
w_c_2_5_mean = zeros(l,1);

for o = 1:l
    
    w_c_0_0_mean(o,1) = d_w_0_0(o+2,1);
    w_c_0_5_mean(o,1) = d_w_0_5(o+2,1);
    w_c_1_0_mean(o,1) = d_w_1_0(o+2,1);
    w_c_1_5_mean(o,1) = d_w_1_5(o+2,1);
    w_c_2_0_mean(o,1) = d_w_2_0(o+2,1);
    w_c_2_5_mean(o,1) = d_w_2_5(o+2,1);
    
end

%Angles:

a = zeros(N,1);
a(1,1) = 0.00;

for q = 2:length(a)

if p == 1

    a(q) = a(q-1) + 0.50;
    
else
    
    a(q) = a(q-1) - 0.50;
    
end

end

%Walk per cycle:

w_c = zeros(N,1);

w_c(1) = mean(w_c_0_0_mean);
w_c(2) = mean(w_c_0_5_mean);
w_c(3) = mean(w_c_1_0_mean);
w_c(4) = mean(w_c_1_5_mean);
w_c(5) = mean(w_c_2_0_mean);
w_c(6) = mean(w_c_2_5_mean);

fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]', a(1), w_c(1))
fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]', a(2), w_c(2))
fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]', a(3), w_c(3))
fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]', a(4), w_c(4))
fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]', a(5), w_c(5))
fprintf('\nWalk per cycle for %.1f [degreees] is %.4f [m]\n\n', a(6), w_c(6))

%Analytical values:

n_a = 6;
m_a = 1;


if p == 1
    
    analy = fopen('analytical_pos.dat');
    
else
    
    analy = fopen('analytical_neg.dat');
    
end


analy_info = (fscanf(analy, '%f', [n_a,m_a]))';
w_c_a = zeros(n_a,1);

for ii = 1:n_a
    
    w_c_a(ii) = analy_info(ii);
    
end


%Plotting angle against walk per cycle, and compare to analytical results:

figure;
hold on
h=gca;
set(h,'fontsize',26)
%plot(a, w_c, 'X');
plot(a, w_c, '--bs','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',10)
plot(a, w_c_a, '--rs','LineWidth',2,'MarkerEdgeColor','r','MarkerFaceColor','r','MarkerSize',10)
%plot(a, r, 'g','linewidth',2);
title('Angle vs. Walk per Cycle');
legend('Numerical', 'Analytical')
xlabel('Angle [deg]');
ylabel('Walk per Cycle [m]');

if p == 1
    
    axis([-0.2 2.7 -0.01 0.55])
    
else
    
    axis([-2.6 0.2 -0.55 0.04])
    
end

grid on
axis square

 
%Calculating difference between numerical and analytical results:

diff = abs(w_c - w_c_a);

fprintf('\nDifference in Walk per cycle for %.4f [m]', diff)

end

fprintf('\n')
