%ANGLEDET.M
%This script opens and reads displacement files/.dat files, and assign the
%values to new matrices. The displacements for the middle node are
%plotted, as well as angle vs. walk per cycle. This is done for the
%detailed angle case.

clear all
close all
close('all')
clc

m = 4851;       %Number of input lines/time steps in the text file
n = 2;          %Number of coloumns
N = 5;          %Number of files
an = 40;        %Counter
        
%Write to screen:

fprintf('\nThe overall walk on seabed slope after 12 cycles')

%Plot:

cc=hsv(N+1);
figure;
hold on
h=gca;
set(h,'fontsize',26)

for s = 1:1:N
    
    %Opening and reading the text files:
    
    disp = fopen(['0_' num2str(an) '_det_middle.dat']);
    
    dispinfo = (fscanf(disp, '%d %f', [n,m]))';
    
    %Assigning to new matrices:

    time_step = dispinfo(:,1);
    displ = dispinfo(:,2);
    
    %Writing to screen:
    
    fprintf('\n..is %.10f [m] for the middle node', displ(m))
    
    plot(time_step,displ,'color',cc(s,:),'linewidth',2);
    
    an = an + 5;

end


line([426 426],[-2 2.5],'linewidth',1)
line([826 826],[-2 2.5],'linewidth',1)
line([1226 1226],[-2 2.5],'linewidth',1)
line([1626 1626],[-2 2.5],'linewidth',1)
line([2026 2026],[-2 2.5],'linewidth',1)
line([2426 2426],[-2 2.5],'linewidth',1)
line([2826 2826],[-2 2.5],'linewidth',1)
line([3226 3226],[-2 2.5],'linewidth',1)
line([3626 3626],[-2 2.5],'linewidth',1)
line([4026 4026],[-2 2.5],'linewidth',1)
line([4426 4426],[-2 2.5],'linewidth',1)
line([4826 4826],[-2 2.5],'linewidth',1)
title('Axial displacement at the middle node');
xlabel('Time step [s]');
ylabel('Displacement [m]');
legend('\alpha = -0.40','\alpha = -0.45','\alpha = -0.50','\alpha = -0.55','\alpha = -0.60')
axis([0 5000 -0.1 0.12])
axis square
%grid on

fprintf('\n')

%Walk per cycle:


k = 12;         %Number of cycles
t = 400;        %One cycle is t time steps
l = k-2;        %The number of cycles "walk per cycle" is based on

c_temp = zeros(k,1);    %Temporary variable for c
c = zeros(k,1);         %Matrix with time steps at a given point in each cycle
c_temp(1) = 426;

w_c = zeros(N,1);

an = 40;

for u = 1:N
    
    %Opening and reading the text files:
    
    disp = fopen(['0_' num2str(an) '_det_middle.dat']);
    
    dispinfo = (fscanf(disp, '%d %f', [n,m]))';
    
    %Assigning to new matrices:

    time_step = dispinfo(:,1);
    displ = dispinfo(:,2);
    
    w = zeros(k,1);
    
    for i = 1:k
    
    c_temp(i+1) = c_temp(i) + t;
    c(i) = c_temp(i);
    
    w(i) = displ(c(i));
             
    end
    
    d_w = zeros(k,1);
    d_w(1) = w(1);
    
    for j = 2:k
    
    d_w(j) = w(j) - w(j-1);
    
    end
    
    %Walk per cycle:
    
    w_c_mean = zeros(l,1);
    
    for o = 1:l
    
    w_c_mean(o,1) = d_w(o+2,1);
    
    end
        
    w_c(u) = mean(w_c_mean);
    
    an = an + 5;
    
    
end


%Angles:

a = zeros(N,1);
a(1,1) = 0.40;

for q = 2:length(a)

    a(q) = a(q-1) + 0.05;
    
end


%Plotting angle against walk per cycle, and fitting a curve to the points:

poly = polyfit(a,w_c,1);        %Poly returns 2 coefficients that fits r = a_1 * a + a_2
r = poly(1) .* a + poly(2);     %Compute a new vector r

figure;
hold on
h=gca;
set(h,'fontsize',26)
%plot(a, w_c, 'X');
plot(a, w_c, '--bs','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',10)
%plot(a, r, 'g','linewidth',2);
title('Angle vs. Walk per Cycle');
xlabel('Angle [deg]');
ylabel('Walk per Cycle [m]');
axis([0.35 0.65 -0.006 0.0125])
grid on
axis square


%Print to screen:

fprintf('\nWalk per cycle for seabed slope')

for v = 1:N

fprintf('\n..angle = -%.2f [degrees] is %.10f [m]', a(v), w_c(v))

end

fprintf('\n \n')

