%READ_FRICTION.M
%The .dat files are imported in the same manner as in transients.m, by
%using the counters f_coeff, f_coeff2 and f_coeff3. The axial displacement
%for each friction is then plotted. After this, the walk per cycle is found
%for each equivalent friction factor, and thus plotted against walk per
%cycle.

clear all
close all
fclose('all')
clc

N = 22;             %Number of .dat files
f_coeff = 10;       %Counters
f_coeff2 = 0;
f_coeff3 = 0;

m = 4851;           %Number of input lines/time steps in the text file
n = 2;              %Number of coloumns

%Print to screen:
fprintf('\nThe overall walk after 12 cycles')

%Plot:

cc=jet(N+1);
figure;
hold on
h=gca;
set(h,'fontsize',19)

for p = 1:N-1
    
    %Opening the different files:
    
    if f_coeff <= 90
        
        disp = fopen(['0_' num2str(f_coeff) '_middle.dat']);
        
        fprintf('\n..for the middle node with equivalent friction factor = 0.%d',f_coeff)
                
    elseif f_coeff <= 180 && f_coeff > 90
        
        disp = fopen(['1_' num2str(f_coeff2) '_middle.dat']);
        
        fprintf('\n..for the middle node with equivalent friction factor = 1.%d',f_coeff2)
        
        f_coeff2 = f_coeff2 + 10;
                
    elseif f_coeff > 180
        
        disp = fopen(['2_' num2str(f_coeff3) '_middle.dat']);
        
        fprintf('\n..for the middle node with equivalent friction factor = 2.%d',f_coeff3)
        
        f_coeff3 = f_coeff3 + 10;
            
    end
    
    f_coeff = f_coeff + 10;
    
    %Reading the files:
    
    dispinfo = (fscanf(disp, '%d %f', [n,m]))';
    
    %Assigning to new matrices:
    
    time_step = dispinfo(:,1);
    displ = dispinfo(:,2);
    
    %Calcultaing overall walk:
    
    w_tot = displ(m);
    
    fprintf('\nis %.4f [m]', w_tot)
        
    
    %Plot:
    
    plot(time_step,displ,'color',cc(p,:),'linewidth',2);
    
end

fprintf('\n')

%Plot:

plot(time_step,displ,'color',cc(N+1,:),'linewidth',2);
line([426 426],[0 0.9],'linewidth',1)
line([826 826],[0 0.9],'linewidth',1)
line([1226 1226],[0 0.9],'linewidth',1)
line([1626 1626],[0 0.9],'linewidth',1)
line([2026 2026],[0 0.9],'linewidth',1)
line([2426 2426],[0 0.9],'linewidth',1)
line([2826 2826],[0 0.9],'linewidth',1)
line([3226 3226],[0 0.9],'linewidth',1)
line([3626 3626],[0 0.9],'linewidth',1)
line([4026 4026],[0 0.9],'linewidth',1)
line([4426 4426],[0 0.9],'linewidth',1)
line([4826 4826],[0 0.9],'linewidth',1)
line([5226 5226],[0 0.9],'linewidth',1)
line([5626 5626],[0 0.9],'linewidth',1)
line([6026 6026],[0 0.9],'linewidth',1)
title('Axial displacement at the middle node with varying equivalent friction coefficient');
xlabel('Time step [s]');
ylabel('Displacement [m]');
legend('\mu = 0.10','\mu = 0.20','\mu = 0.30','\mu = 0.40','\mu = 0.50','\mu = 0.60','\mu = 0.70','\mu = 0.80','\mu = 0.90','\mu = 1.00','\mu = 1.10','\mu = 1.20','\mu = 1.30','\mu = 1.40','\mu = 1.50','\mu = 1.60','\mu = 1.70','\mu = 1.80','\mu = 1.90','\mu = 2.00','\mu = 2.10','\mu = 2.20');
axis([0 6100 0 0.8])
axis square


%Walk per cycle, and friction vs. walk per cycle

k = 12;                 %Number of cycles
t = 400;                %One cycle is t time steps
l = k-2;

c_temp = zeros(k,1);    %Temporary variable for c
c = zeros(k,1);         %Matrix with time steps at a given point in each cycle
c_temp(1) = 426;        %Temporary variable for c

f_coeff = 10;           %Counter
f_coeff2 = 0;
f_coeff3 = 0;

w_c = zeros(N+1,1);     %Walk per cycle


for q = 1:N
    
    %Opening and reading all the files, again (this may take longer time, 
    %but it makes the script easier to read):
    
    if f_coeff <= 90
        
        disp = fopen(['0_' num2str(f_coeff) '_middle.dat']);
                
    elseif f_coeff <= 180 && f_coeff > 90
        
        disp = fopen(['1_' num2str(f_coeff2) '_middle.dat']);
        
        f_coeff2 = f_coeff2 + 10;
                
    elseif f_coeff > 180
        
        disp = fopen(['2_' num2str(f_coeff3) '_middle.dat']);
                
        f_coeff3 = f_coeff3 + 10;
            
    end
    
    f_coeff = f_coeff + 10;
    
    
    dispinfo = (fscanf(disp, '%d %f', [n,m]))';
    
    %Assigning values to matrices
    
    time_step = dispinfo(:,1);
    displ = dispinfo(:,2);
    
    %Displacement for each cycle:
    
    w = zeros(k+1,1);
    
    for i = 1:k
    
    c_temp(i+1) = c_temp(i) + t;
    c(i) = c_temp(i);
    
    w(i) = displ(c(i));             %The displacement at a given time step
             
    end
    
    %Finding the difference in displacement from cycle to cycle:
    
    d_w = zeros(k,1);
    d_w(1) = w(1);
    
    for j = 2:k+1
    
    d_w(j) = w(j) - w(j-1);
    
    end

    %Walk per cycle:
    
    w_c_mean = zeros(l,1);
    
    for o = 1:l
    
    w_c_mean(o,1) = d_w(o+2,1);
    
    end
    
    w_c(q) = mean(w_c_mean);
     
end

%Walk per cycle in plot:

w_c_plot = zeros(N,1);

for s = 1:N
    
    w_c_plot(s) = w_c(s);
    
end


%Making the friction vector:

f = zeros(N,1);       %Friction
f(1) = 0.1;             %Starting point

for r = 1:N-1
    
    f(r+1) = f(r) + 0.1;
    
end
    

%Plotting angle against walk per cycle:

figure;
hold on
h=gca;
set(h,'fontsize',26)
plot(f, w_c_plot, '--bs','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',10)
title('Friction vs. Walk per Cycle');
xlabel('Equivalent Friction Factor \mu [-]');
ylabel('Walk per Cycle [m]');
axis([0 2.5 0 0.08])
grid on
axis square


%Print to screen:

fprintf('\nWalk per cycle for')

for u = 1:N

fprintf('\n..equivalent friction factor = %.2f [-] is %.4f [m]', f(u), w_c_plot(u))

end

fprintf('\n \n')
