%ANALYTICAL_SCR.M
%This script calculates the analytical values for the SCR case study

close all
clear all
clc

OD = 0.4229              ;   %outer diamater [m]
r_mean = 0.1429          ;   %mean radius [m]
t = 0.0191               ;   %Wall thickness
Ae = 3.14*(OD/2)^2       ;   %Area, outside diameter [m^2]
Ai = 1                   ;   %Area, inside diameter
Am = 3.14*r_mean^2       ;   %Area, mean
As = 1                   ;   %Area, pipe wall
E = 207000000000         ;   %Young's Modulus
EA = E*Am                ;   %axial stiffness
W = 43.3                 ;   %submerged unit weight [N/m]
L = 3000                 ;   %length of pipeline
p_i = 15800000           ;   %internal pressure
p_e = 30700000           ;   %external pressure
p_2 = p_i                ;   %constant pressure
p_1 = p_i                ;   %constant pressure
kappa = 1.17*10^-5       ;   %coeff of thermal expansion
theta = 78               ;   %operating temperature
theta2 = 52.25           ;   %temperature at last time step for the last node from temp files
theta1 = 58.70           ;   %temperature at the first time step at the first node from temp files
nu = 0.3                 ;   %Poisson's ratio

mu = 0.279               ;   %friction coeff
alfa = 0                 ;   %seabed slope

f = mu*W                 ;   %axial friction force

Sr = 5000                ;   %SCR tension [N]

%General equations:

deltaP = (-(p_2 - p_1)*Ai*(1 - (2*nu))) - (E*As*kappa*(theta2 - theta1)); %change in fully constrained force

f_star = (abs(deltaP))/L;    %friction force at which cyclic constraint occurs

fprintf('\nThe change in fully constrained force is %.4f [N]', deltaP)
fprintf('\nf_star is %.4f [N/m]', f_star)




%SCR case:
fprintf('\n\nThe analytical results for the SCR case:')

deltaSf = Sr - (L*f);    %change in effective axial force over X_ab (SCR)
delta_eps = ((deltaSf - deltaP))/(EA);   %change in strain 
deltar = (((abs(deltaP)) + Sr - (f*L))*Sr)/(EA*f);   %walk per cycle for the SCR case

fprintf('\nThe change in effective axial force over X_ab is %.4f [N]', deltaSf)
fprintf('\nThe change in strain is %.4f [-]', delta_eps)
fprintf('\nThe walk per cycle for the SCR case is %.4f [m] \n', deltar)

%Writing to file:

fid = fopen('analytical_scr.dat','a');
fprintf(fid,'%.4f \n\n',deltar);

