%SCR.M
%Opens and reads all .dat files, and plot different plots to be able to
%assess the effect of SCR. The walk per cycle is written to screen.

clear all
close all
clc

N = 2;      %Number of files
m = 4851;   %Number of input lines/time steps in the text file
n = 2;      %Number of coloumns

%Values so that walk per cycle can be found:

k = 12;         %Number of cycles
t = 400;        %One cycle is t time steps
l = k-2;        %The number of cycles "walk per cycle" is based on

c_temp = zeros(k,1);    %Temporary variable for c
c = zeros(k,1);         %Matrix with time steps at a given point in each cycle
c_temp(1) = 426;

w_c = zeros(N,1);

%Plot:

cc=jet(N+1);
figure;
hold on
h=gca;
set(h,'fontsize',26)

for p = 1:N
        
    disp = fopen(['scr_' num2str(p) '.dat']);
    dispinfo = (fscanf(disp, '%d %f', [n,m]))';
    
    time_step = dispinfo(:,1);
    displ = dispinfo(:,2);
    
    %Print to screen:
    
    w_tot = displ(m);
    fprintf('\nThe overall walk after 12 cycles for Case %d', p)
    fprintf('\nis %.4f [m]', w_tot)
    
    w = zeros(k,1);
    
    for i = 1:k
    
    c_temp(i+1) = c_temp(i) + t;
    c(i) = c_temp(i);
    
    w(i) = displ(c(i));
             
    end
    
    d_w = zeros(k,1);
    d_w(1) = w(1);
    
    for j = 2:k
    
    d_w(j) = w(j) - w(j-1);
    
    end
    
    %Walk per cycle:
    
    w_c_mean = zeros(l,1);
    
    for o = 1:l
    
    w_c_mean(o,1) = d_w(o+2,1);
    
    end
        
    w_c(p) = mean(w_c_mean);
    
    %Plot:
    
    plot(time_step,displ,'color',cc(p,:),'linewidth',2);
    
end

fprintf('\n')

%Plot:

line([426 426],[0 0.9],'linewidth',1)
line([826 826],[0 0.9],'linewidth',1)
line([1226 1226],[0 0.9],'linewidth',1)
line([1626 1626],[0 0.9],'linewidth',1)
line([2026 2026],[0 0.9],'linewidth',1)
line([2426 2426],[0 0.9],'linewidth',1)
line([2826 2826],[0 0.9],'linewidth',1)
line([3226 3226],[0 0.9],'linewidth',1)
line([3626 3626],[0 0.9],'linewidth',1)
line([4026 4026],[0 0.9],'linewidth',1)
line([4426 4426],[0 0.9],'linewidth',1)
line([4826 4826],[0 0.9],'linewidth',1)
line([5226 5226],[0 0.9],'linewidth',1)
line([5626 5626],[0 0.9],'linewidth',1)
line([6026 6026],[0 0.9],'linewidth',1)
title('Axial displacement at the middle node for case with/without SCR');
xlabel('Time step [s]');
ylabel('Displacement [m]');
legend('With SCR', 'Without SCR')
axis([0 5000 0 0.3])
axis square


%Print to screen:

fprintf('\nThe walk per cycle for case 1')
fprintf('\n is %.4f [m]', w_c(1))
fprintf('\nThe walk per cycle for case 2')
fprintf('\n is %.4f [m]', w_c(2))

fprintf('\n')


%Analytical values:

n_a = 2;
m_a = 1;

analy = fopen('analytical_scr.dat');
    
analy_info = (fscanf(analy, '%f', [n_a,m_a]))';
w_c_a = zeros(n_a,1);

for ii = 1:n_a
    
    w_c_a(ii) = analy_info(ii);
    
end

t = zeros(n_a,1);
t(1) = 5000;
t(2) = 0;


%Plotting tension against walk per cycle, and compare to analytical results:

figure;
hold on
h=gca;
set(h,'fontsize',26)
plot(t, w_c, '--bs','LineWidth',2,'MarkerEdgeColor','b','MarkerFaceColor','b','MarkerSize',10)
plot(t, w_c_a, '--rs','LineWidth',2,'MarkerEdgeColor','r','MarkerFaceColor','r','MarkerSize',10)
title('Angle vs. Walk per Cycle');
legend('Numerical', 'Analytical')
xlabel('SCR Tension [N]');
ylabel('Walk per Cycle [m]');
axis([-5 5050 -0.01 0.5])
grid on
axis square

 
%Calculating difference between numerical and analytical results:

for jj = 1:1

diff = abs(w_c - w_c_a);

fprintf('\nDifference in Walk per cycle is %.4f [m]', diff)

end

fprintf('\n')

    
    