%TRANSIENTS.M
%Each .dat file containing time steps and corresponding temperature are
%opened, read and closed. The values are then assigned to new matrices, and
%plotted.

clear all
close all
clc


%Sizing, and preallocating:

m = 363;    %Number of .dat files
n = 322;    %Number of rows in each file
k = 2;      %Number of coloumns in each file

trans_read = zeros(n,k);    %Preallocating
trans = zeros(n,m);         %Preallocating


for i = 1:m
    
    odd = 1;    %Start value for counter "odd"
    even = 2;   %Start value for counter "even"
    
    %Opening each file:
    
    transient = ['File' num2str(i) '.dat'];     %Naming each of the files
    trans_open = fopen(transient);              %Opening each of the files
    
    %Reading each file
    
    trans_temp = (fscanf(trans_open, '%f')); 
    
    %Closing each file:
    
    fclose('all');
    
    for j = 1:n
    
        %Assigning the values from each file to the matrix trans_read:
    
        trans_read(j,1) = trans_temp(odd,1);
        trans_read(j,2) = trans_temp(even,1);
    
        %Odd values are time steps and even values are temperatures. Counting:
    
        if odd < 643 
        
            odd = odd + 2;
            even = even + 2;
            
        else
            
            odd = odd;
            
        end
        
    %Assigning the temperatures to one large matrix, trans(n,m):
    
    trans(j,i) = trans_read(j,2);       %Only assigning the transients
            
    end
    
    
        
end


%Plotting the transients:

L = 3000;               %Length of pipeline
delta = L/(m-1);        %Vector step
length = 0:delta:L;     %Length vector --> plotted against the transients

figure;
hold on
h=gca;
set(h,'fontsize',22)

r = 1;              %Color values: r
g = 0.23;           %Color values: g
b = 0.0;            %Color values: b

for o = 1:n
    
    plot(length,trans(o,:),'color',[r g b],'linewidth',2);
    
end

title('Temperature Transients over the Pipeline Length');
xlabel('Distance from Well [m]');
ylabel('Temperature [ ^{\circ}C]');
axis([0 3001 0 60])
%grid on






