#####################################################################
## Generating SIMLA seabed for screening of Snakelay configurations #
#####################################################################

from pylab import *
import math

#------------------------------------------------------------------#
# Input Section:

lenTOT       = 3000.0      # Total length of model
depth        = -130.        # Depth of model
CurveLength  = 50.        # Lenght of expansion curve
dseabed      = 1.0         # Seabed element length
CurveRadius  = 250.0       # Expansion Curve Radius
breadth      = 20.         # Breadth of seabed

filename   ='snake_250m_radius_50m_curvelength.txt'  #Seabed name

#------------------------------------------------------------------#

sectAngle  = CurveLength/CurveRadius
startAngle = 3*math.pi/2-sectAngle/2
startX     = CurveRadius*cos(startAngle)
startY     = CurveRadius*sin(startAngle)
b          = [startAngle*CurveRadius]
angle      = [startAngle]
x1         = [];x2         = []
y1         = [];y2         = []
x3         = [];y3         = []
xstr       = [];ystr       = []
xstrL      = [];xstrR      = []
ystrL      = [];ystrR      = []

# Generate first straight section
l1 = arange(0.,(lenTOT-CurveLength)/2+1,dseabed)
x1 = l1*cos(sectAngle/2)
y1 = -l1*sin(sectAngle/2)

# Generate curve-matrix
for i in range(1,int(CurveLength/dseabed)):
    b.append(b[i-1]+dseabed)
    angle.append(b[i]/CurveRadius)
    x2temp=CurveRadius*cos(angle[i])
    y2temp=CurveRadius*sin(angle[i])
    x2.append(x1[-1]+abs(startX)+x2temp)
    y2.append(-startY - ((lenTOT-CurveLength)/2)*sin(sectAngle/2)+y2temp)

# Generate last straight section
x3 = list(x1+x2[-1]+dseabed)
y3 = list(y1)
y3.reverse()

# Generate lists for Seabed Main Route
xstr = [-10] + list(x1) + x2 + x3 + [x3[-1]+10] + [x3[-1]+11]
ystr = [10*tan(sectAngle/2)] + list(y1) + y2 + y3 + [10*tan(sectAngle/2)] + [11*tan(sectAngle/2)]

# Generate Seabed Breadth
for i in range(size(ystr)-1):
    delta = math.atan((ystr[i+1]-ystr[i])/(xstr[i+1]-xstr[i]))
    xstrL.append(xstr[i]-breadth*cos(math.pi/2-delta))
    xstrR.append(xstr[i]+breadth*cos(math.pi/2-delta))
    ystrL.append(ystr[i]+breadth*sin(math.pi/2-delta))
    ystrR.append(ystr[i]-breadth*sin(math.pi/2-delta))
    
print len(y1), len(y2), len(y3)
print len(x1), len(x2), len(x3)
print x1[0], x1[-1],x2[0], x2[-1],x3[0], x3[-1] 
print size(ystr),size(xstrL), size(xstrR)

# Writing strings to file

ofile  = open(filename, 'w')

for i in range(size(ystr)-1):
    ofile.write('%15.5f%15.5f%15.5f%15.5f%15.5f%15.5f'%   (xstr[i],  ystr[i],  depth, 0, 0, 1.0))
    ofile.write('%15.5f%15.5f%15.5f%15.5f%15.5f%15.5f'%   (xstrL[i], ystrL[i], depth, 0, 0, 1.0))
    ofile.write('%15.5f%15.5f%15.5f%15.5f%15.5f%15.5f\n'% (xstrR[i], ystrR[i], depth, 0, 0, 1.0))
ofile.close()
#
figure(1)
plot(xstr,ystr)
plot(xstrL,ystrL)
plot(xstrR,ystrR)
grid(True)
show()
